/*  Jcurzez - A free Java implementation of curses
 *  Copyright (C) 2001, 2006  Thomas G. Girard <thomas.g.girard@free.fr>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.nongnu.savannah.jcurzez.test;

import atomicsets.OrderedLock;
import org.nongnu.savannah.jcurzez.*;
import org.nongnu.savannah.jcurzez.frame.*;

/**
 * Tests the {@link jcurzez.Window Window} object.
 *
 * @author Thomas Girard
 * @version 1.0.0
 */
public class ThreadedWindowsMain {
	
	public static String frameClassName;
	
    /**
     * Runs the {@link org.nongnu.savannah.jcurzez.test.Test} program using the
     * <code>Window</code> object.
     * <br>
     * One can specify the frame to use with
     * <code>--frame=<i>frameclassname</i></code>.
     */
    public static void main(String[] args) throws Exception {
		if (args.length > 0) {
		    if (args[0].startsWith("--frame=")) {
		    	frameClassName = args[0].substring(8);
		    } else {
		    	throw new
			    	IllegalArgumentException("The only parameter that can be " +
						     "used is --frame=_classname_");
		    }
		} else {
		    frameClassName = "org.nongnu.savannah.jcurzez.frame.SingleFrame";
		}
		
		Screen.getScreen().touch();
		Screen.getScreen().refresh();
	
		for (int i = 0 ; i < 4; i++){
			new WindowThread((i/2*12)+1, (i%2*40)+1).start();
		}
		
		
    }
}

class WindowThread extends Thread{
	int top;
	int left;
	
	WindowThread(int top, int left){
		this.top = top;
		this.left = left;
	}
	
	public void run(){
		try{
			Frame frame = (Frame) (Class.forName(ThreadedWindowsMain.frameClassName).newInstance());
			final Window win = /*new*/ Window.getWindow(new Rectangle(left, top, left+30, top+10,
				      new Pen(ForegroundColor.YELLOW,
					      BackgroundColor.BLUE,
					      Attribute.BOLD, new OrderedLock()),
				      new Pen(ForegroundColor.GREEN,
					      BackgroundColor.RED,
					      Attribute.NORMAL, new OrderedLock()), new OrderedLock()),
			frame);
			
			win.clear();
			win.refresh();
			
			if (top==1 && left==1){
				win.stressConcurrency = true;
			}
			
			new Thread(){
				public void run(){
					new Test2(win, 1500);
				}
			}.start();
			
			new Test1(win, 1500);
			
		}catch(Exception e){
			System.err.println("WindowThread failure!");
			e.printStackTrace();
		}
	}
}

class Test2 {
    public Test2(AbstractWindow aw, long pause) {
	try {
	    aw.printString("ABCDEFGHIJKLMNOP\n");
	    Thread.sleep(pause);
	    aw.printString("QRSTUVWXYZ\n");
	    aw.refresh();
	    Thread.sleep(pause);
	    //synchronized(aw.getCursor()){
	    	aw.setCursorXY(0,5);
	    	aw.insertString("Hi there!");
	    //}
	    aw.refresh();

//	    //moving
//	    aw.getCursor().setY(1);
//	    aw.refresh();
//	    Thread.sleep(pause);
//
//	    //line insertion
//	    aw.insertLine();
//	    aw.refresh();
//	    Thread.sleep(pause);
//
//	    //line deletion
//	    aw.deleteLine();
//	    aw.refresh();
//	    Thread.sleep(pause);
//
//	    //Return to origin.
//	    aw.setCursorXY(0,0);
//	    aw.refresh();
//	    Thread.sleep(pause);
//
//	    //character deletion
//	    aw.deleteChar();
//	    aw.refresh();
//	    Thread.sleep(pause);
//
//	    //character insertion
//	    aw.insertChar('1');
//	    aw.refresh();
//	    Thread.sleep(pause);
//
//	    //string insertion
//	    //aw.insertChar('!');
//	    aw.insertString("Whatever");
//	    aw.refresh();
//	    Thread.sleep(pause);
//
//	    //clear to end of line
//	    aw.clearToEndOfLine();
//	    aw.refresh();
//	    Thread.sleep(pause);
//
//	    //clear to bottom
//	    aw.clearToBottom();
//	    aw.refresh();
//	    Thread.sleep(pause);
//
//	    //writing in the bottom right corner
//	    aw.setCursorXY(aw.getRectangle().getWidth() -1,
//				 aw.getRectangle().getHeight() -1);
//	    aw.insertChar((int) 'O');
//	    aw.refresh();
//	    Thread.sleep(pause);
//
//	    //clear
//	    aw.setCursorXY(0, 0);
//
//	    Pen pen = aw.getRectangle().getFillingPen();
//	    pen.setBackgroundColor(BackgroundColor.BLACK);
//	    pen.setForegroundColor(ForegroundColor.WHITE);
//	    pen.setAttribute(Attribute.NORMAL);
//	    aw.clear();
//	    aw.refresh();
//	    Thread.sleep(pause);
	} catch(InterruptedException ie) {
	    System.out.println("Interrupted");
	} catch(Throwable t) {
	    System.out.println(t.getMessage());
	}
    }
}


class Test1 {
    public Test1(AbstractWindow aw, long pause) {
	try {
	    //wrapping
	    aw.printString("123456789012345678901234567890123456789" +
			   "01234567890123456789012345678901234567890" +
			   "1234567890\n");
	    aw.printString("1234567890123456789012345678901234567890\n");
	    aw.refresh();
	    Thread.sleep(pause);

	    //moving
	    aw.setCursorXY(0,1);
	    aw.refresh();
	    Thread.sleep(pause);

	    //line insertion
	    aw.insertLine();
	    //aw.insertChar('\n');
	    aw.refresh();
	    Thread.sleep(pause);

	    //line deletion
	    aw.deleteLine();
	    aw.refresh();
	    Thread.sleep(pause);

	    //Return to origin.
	    aw.setCursorXY(0,0);
	    aw.refresh();
	    Thread.sleep(pause);

	    //character deletion
	    aw.deleteChar();
	    aw.refresh();
	    Thread.sleep(pause);

	    //character insertion
	    aw.insertChar('1');
	    aw.refresh();
	    Thread.sleep(pause);

	    //string insertion
	    //aw.insertChar('!');
	    aw.insertString("Whatever");
	    aw.refresh();
	    Thread.sleep(pause);

	    //clear to end of line
	    aw.clearToEndOfLine();
	    aw.refresh();
	    Thread.sleep(pause);

	    //clear to bottom
	    aw.clearToBottom();
	    aw.refresh();
	    Thread.sleep(pause);

	    //writing in the bottom right corner
	    aw.setCursorXY(aw.getRectangle().getWidth() -1,
				 aw.getRectangle().getHeight() -1);
	    aw.insertChar((int) 'O');
	    aw.refresh();
	    Thread.sleep(pause);

	    //clear
	    aw.setCursorXY(0, 0);

	    Pen pen = aw.getRectangle().getFillingPen();
	    pen.setBackgroundColor(BackgroundColor.BLACK);
	    pen.setForegroundColor(ForegroundColor.WHITE);
	    pen.setAttribute(Attribute.NORMAL);
	    aw.clear();
	    aw.refresh();
	    Thread.sleep(pause);
	} catch(InterruptedException ie) {
	    System.out.println("Interrupted");
	} catch(Throwable t) {
	    System.out.println(t.getMessage());
	}
    }
}
