/*  Jcurzez - A free Java implementation of curses
 *  Copyright (C) 2001, 2006  Thomas G. Girard <thomas.g.girard@free.fr>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.nongnu.savannah.jcurzez.test;

import atomicsets.OrderedLock;
import org.nongnu.savannah.jcurzez.*;

/**
 * Show how one can simply show and hide a window.
 *
 * @version 1.0.0
 * @author Thomas Girard
 */
public class TwoWindows {
    public static void main(String[] args) throws Exception {
	Window win1 = /*new*/ Window.getWindow(new Rectangle(10, 10, 50, 20,
					      new Pen(ForegroundColor.YELLOW,
						      BackgroundColor.BLUE,
						      Attribute.BOLD, new OrderedLock()),
					      new Pen(ForegroundColor.WHITE,
						      BackgroundColor.BLUE,
						      Attribute.UNDERLINE, new OrderedLock()), new OrderedLock()));
	win1.printString("This is the first window. " +
			 "It has a long text, which ");
	win1.printString("spans over multiple lines, and is hidden by the " +
			 "second window\n");
	win1.refresh();
	Window win2 = /*new*/ Window.getWindow(win1,
				 new Rectangle(12, 12, 45, 15,
					       new Pen(ForegroundColor.YELLOW,
						       BackgroundColor.RED,
						       Attribute.NORMAL, new OrderedLock()),
					       new Pen(ForegroundColor.YELLOW,
						       BackgroundColor.RED,
						       Attribute.BOLD, new OrderedLock()), new OrderedLock()));
	win2.printString("Press enter to hide this window");
	win2.refresh();
	Pen drawingPen = win1.getRectangle().getDrawingPen();
	drawingPen.setForegroundColor(ForegroundColor.RED);
	drawingPen.setAttribute(Attribute.BOLD);
	win1.printString("Now press enter again to make the second window " +
			 "reappear\n");
	try {System.in.read(); } catch (java.io.IOException ioe) {}
	win1.touch();
	win1.refresh();
	win2.clear();
	win2.printString("Press enter again to hide this window and exit");
	try {System.in.read(); } catch (java.io.IOException ioe) {}
	win2.touch();
	win2.refresh();
	try {System.in.read(); } catch (java.io.IOException ioe) {}
	win1.touch();
	win1.refresh();
    }
}
