/*  Jcurzez - A free Java implementation of curses
 *  Copyright (C) 2001, 2006  Thomas G. Girard <thomas.g.girard@free.fr>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.nongnu.savannah.jcurzez.io;

import org.nongnu.savannah.jcurzez.Screen;

import java.io.OutputStream;
import java.io.IOException;

/**
 * This class is a hack to replace <code>System.out</code>
 * (and <code>System.err</code>) so that all printed chars use <b>Jcurzez</b>.
 *
 * @author Thomas Girard
 * @version 1.0.0
 */
public class JcurzezOutputStream extends OutputStream {
    /** The screen where to send characters. */
    private final Screen screen;

    /**
     * Does actually nothing.
     */
    public JcurzezOutputStream(Screen screen) {
	this.screen = screen;
    }

    /**
     * Write specified character at current position.
     *
     * @param   b the character to write.
     * @exception IOException if an error occurs while writing.
     *            It is currently unused.
     */
    public void write(int b) throws IOException {
	b &= 0x000000FF;
//	synchronized(screen) {
	    screen.printChar(b);

	    if (b == '\n')
		screen.refresh();
//	}
    }

    /**
     * Flushes the output stream, i&#46;e&#46; empty internal
     * buffer. This method invokes {@link jcurzez.Screen#refresh}.
     *
     * @exception IOException is never thrown.
     */
    public void flush() throws IOException {
//	synchronized(screen) {
	    screen.refresh();
//	}
    }

    /**
     * This method does nothing.
     *
     * @exception IOException never thrown.
     */
    public void close() throws IOException {
    }
}
