/*  Jcurzez - A free Java implementation of curses
 *  Copyright (C) 2001, 2006  Thomas G. Girard <thomas.g.girard@free.fr>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.nongnu.savannah.jcurzez.test;

import org.nongnu.savannah.jcurzez.*;
import java.util.Date;
import java.text.SimpleDateFormat;


/**
 * A little test program to test <b>Jcurzez</b> thread safety.
 *
 * @author Thomas Girard
 * @version 1.0.0
 */
public class ThreadSafety {
    /**
     * The thread group that owns all the threads this
     * test will create.
     */
    private static final ThreadGroup threads;


    /**
     * We set a shutdown hook to kill all threads upon termination.
     */
    static {
	threads = new ThreadGroup("clocks");
	/*Runtime.getRuntime().addShutdownHook(new Thread() {
		public void run() {
		    synchronized(threads) {
			//Kill'em all
			threads.interrupt();
		    }
		}
		});*/
    }

    /** To display the date like I want. */
    private static final SimpleDateFormat df = new SimpleDateFormat("HH:mm:ss");

    /** The screen. */
    private static final Screen screen = Screen.getScreen();

    /** Width of the screen. */
    private static final int    width  = screen.getRectangle().getWidth();

    /** Height of the screen. */
    private static final int    height = screen.getRectangle().getHeight();

    /**
     * Writes time at position <code>x</code>, <code>y</code>
     */
    private static class ClockThread extends Thread {
	private long t1;
	private final Date d;
	private final int x, y;

	private ClockThread(int x, int y) {
	    super(threads, "Clock at x: " + x + ", y: " + y);
	    this.x = x;
	    this.y = y;
	    this.t1 = System.currentTimeMillis();
	    this.d = new Date(t1);
	    setDaemon(true);
	}

	public void run() {
	    while(!isInterrupted()) {
		t1 = System.currentTimeMillis();
		d.setTime(t1);
//		synchronized(screen) {
//		    screen.setCursorXY(x, y);
//		    screen.printString(df.format(d));
//		} 
		printDate(screen);

	    screen.refresh();
		try {
		    sleep(1000);
		} catch(InterruptedException ie) {
		    return;
		}
	    }
	}
	
	void printDate(/*unitfor(B)*/Screen s){
		s.setCursorXY(x,y);
		s.printString(df.format(d));
	}
    }


    /**
     * Test thread safety by having multiple threads write on the screen.
     *
     * @exception InterruptedException raised if the sleep is interrupted.
     */
    public static void main(String[] args) throws InterruptedException {
	screen.clear();
	screen.setCursorVisibility(0);
	screen.refresh();

	for (int i = 0; i + 8 < width; i += 9) {
	    for(int j = 0; j < height; j ++) {
		new ClockThread(i, j).start();
	    }
	}

	//Sleep for 10 seconds. Since threads are daemons,
	//they will be killed after this sleep.
	Thread.sleep(10000);
    }
}
