/*  Jcurzez - A free Java implementation of curses
 *  Copyright (C) 2001, 2006  Thomas G. Girard <thomas.g.girard@free.fr>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "jcurzez_win.h"

#include <windows.h>
#include <stdio.h>

static HANDLE hOut;
static CONSOLE_SCREEN_BUFFER_INFO csbi;

/**
 * To see:
 * SetConsoleCtrlHandler to change beahvior on CTRL-C
 * SetConsoleMode for one char at a time input.
 */


/**
 * From WIN.H
 * #define FOREGROUND_BLUE	1
 * #define FOREGROUND_GREEN	2
 * #define FOREGROUND_RED	4
 * #define FOREGROUND_INTENSITY	8
 * #define BACKGROUND_BLUE	16
 * #define BACKGROUND_GREEN	32
 * #define BACKGROUND_RED	64
 * #define BACKGROUND_INTENSITY	128
 */
JNIEXPORT jint JNICALL
Java_jcurzez_peer_win_PeerScreen__1begin (JNIEnv *env, jclass clazz)
{

  hOut = GetStdHandle (STD_OUTPUT_HANDLE);
  if (hOut == INVALID_HANDLE_VALUE) {
    return -1;
  }
  GetConsoleScreenBufferInfo (hOut, &csbi);
  return 0;
}


JNIEXPORT void JNICALL
Java_jcurzez_peer_win_PeerScreen__1gotoXY (JNIEnv *env,
					   jclass clazz,
					   jint x,
					   jint y)
{
  COORD where_to_move;

  where_to_move.X = (SHORT) x;
  where_to_move.Y = (SHORT) y;

  SetConsoleCursorPosition(hOut, where_to_move);
}


JNIEXPORT jint JNICALL
Java_jcurzez_peer_win_PeerScreen__1getFirstX (JNIEnv *env,
					      jclass clazz)
{
  return csbi.dwCursorPosition.X;
}

JNIEXPORT jint JNICALL
Java_jcurzez_peer_win_PeerScreen__1getFirstY (JNIEnv *env,
					      jclass clazz)
{
  return csbi.dwCursorPosition.Y;
}

JNIEXPORT void JNICALL
Java_jcurzez_peer_win_PeerScreen__1printCell (JNIEnv *env,
					      jclass clazz,
					      jint x,
					      jint y,
					      jint character,
					      jshort colors,
					      jbyte attribute)
{
  WORD attributes;
  COORD where_to_write;
  DWORD dummy;

  LPSTR string = " ";
  string[0] = (char) character;

  where_to_write.X = (SHORT) x;
  where_to_write.Y = (SHORT) y;

  attributes = (WORD) colors;

  /*
   * Only two attributes: HIGH_INTENSITY_FG and HIGH_INTENSITY_BG.
   * @todo
   */
  WriteConsoleOutputAttribute (hOut, &attributes, 1, where_to_write, &dummy);
  WriteConsoleOutputCharacter (hOut, string, 1, where_to_write, &dummy);
}

JNIEXPORT jint JNICALL
Java_jcurzez_peer_win_PeerScreen__1getColumns (JNIEnv *env, jclass clazz)
{
  return (jint) csbi.dwSize.X;
}

JNIEXPORT jint JNICALL
Java_jcurzez_peer_win_PeerScreen__1getLines (JNIEnv *env, jclass clazz)
{
  return (jint) csbi.dwSize.Y;
}

JNIEXPORT void JNICALL
Java_jcurzez_peer_win_PeerScreen__1setCursorVisibility (JNIEnv *env,
							jclass clazz,
							jint v)
{
  CONSOLE_CURSOR_INFO cci;

  cci.bVisible = TRUE;

  switch(v) {
  case 0:
      cci.bVisible = FALSE;
      break;
  case 1:
      cci.dwSize = 80;
      break;
  case 2:
  default:
      cci.dwSize = 100;
  }
  SetConsoleCursorInfo (hOut, &cci);
}

JNIEXPORT void JNICALL
Java_jcurzez_peer_win_PeerScreen__1beep (JNIEnv *env, jclass clazz)
{
  printf("\a");
}

JNIEXPORT void JNICALL
Java_jcurzez_peer_win_PeerScreen__1end (JNIEnv *env, jclass clazz)
{
  //nothing to do here.
}


JNIEXPORT void JNICALL
Java_jcurzez_peer_win_PeerScreen__1update (JNIEnv *env, jclass clazz)
{
  //nothing to do here.
  //an optimized version could use another CONSOLE_SCREEN_BUFFER_INFO
}


JNIEXPORT jint JNICALL
JNI_OnLoad(JavaVM *vm, void *reserved)
{
	return JNI_VERSION_1_2;
}

JNIEXPORT void JNICALL
JNI_OnUnload(JavaVM *vm, void *reserved)
{
}

BOOL WINAPI __declspec(dllexport) LibMain(HINSTANCE hDLLInst, DWORD fdwReason, LPVOID lpvReserved)
{
	return TRUE;
}
