/*  Jcurzez - A free Java implementation of curses
 *  Copyright (C) 2001, 2006  Thomas G. Girard <thomas.g.girard@free.fr>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.nongnu.savannah.jcurzez;

/**
 * This class contains all box drawing characters, according
 * to Unicode Standard, version 3.0.
 * The description of this set of characters is available
 * from the Unicode Consortium at:
 * <ul>
 * <li><a href="http://www.unicode.org">http://www.unicode.org</a></li>
 * </ul>
 *
 * <p>
 * Peer classes are free to display these values as they want.
 *
 * @author Thomas Girard
 * @version 1.0.0
 */
public final class BoxDrawing {
    public static final char
	LIGHT_VERTICAL_AND_RIGHT = '\u251C',
	VERTICAL_LIGHT_AND_RIGHT_HEAVY_ = '\u251D',
	UP_HEAVY_AND_RIGHT_DOWN_LIGHT = '\u251E',
	DOWN_HEAVY_AND_RIGHT_UP_LIGHT = '\u251F',
	VERTICAL_HEAVY_AND_RIGHT_LIGHT_ = '\u2520',
	DOWN_LIGHT_AND_RIGHT_UP_HEAVY = '\u2521',
	UP_LIGHT_AND_RIGHT_DOWN_HEAVY = '\u2522',
	HEAVY_VERTICAL_AND_RIGHT = '\u2523',
	LIGHT_VERTICAL_AND_LEFT = '\u2524',
	VERTICAL_LIGHT_AND_LEFT_HEAVY = '\u2525',
	UP_HEAVY_AND_LEFT_DOWN_LIGHT = '\u2526',
	DOWN_HEAVY_AND_LEFT_UP_LIGHT = '\u2527',
	VERTICAL_HEAVY_AND_LEFT_LIGHT_ = '\u2528',
	DOWN_LIGHT_AND_LEFT_UP_HEAVY = '\u2529',
	UP_LIGHT_AND_LEFT_DOWN_HEAVY = '\u252A',
	HEAVY_VERTICAL_AND_LEFT = '\u252B',
	LIGHT_DOWN_AND_HORIZONTAL = '\u252C',
	LEFT_HEAVY_AND_RIGHT_DOWN_LIGHT = '\u252D',
	RIGHT_HEAVY_AND_LEFT_DOWN_LIGHT = '\u252E',
	DOWN_LIGHT_AND_HORIZONTAL_HEAVY = '\u252F',
	DOWN_HEAVY_AND_HORIZONTAL_LIGHT = '\u2530',
	RIGHT_LIGHT_AND_LEFT_DOWN_HEAVY = '\u2531',
	LEFT_LIGHT_AND_RIGHT_DOWN_HEAVY = '\u2532',
	HEAVY_DOWN_AND_HORIZONTAL = '\u2533',
	LIGHT_UP_AND_HORIZONTAL = '\u2534',
	LEFT_HEAVY_AND_RIGHT_UP_LIGHT = '\u2535',
	LIGHT_HORIZONTAL = '\u2500',
	HEAVY_HORIZONTAL = '\u2501',
	LIGHT_VERTICAL = '\u2502',
	HEAVY_VERTICAL = '\u2503',
	LIGHT_TRIPLE_DASH_HORIZONTAL = '\u2504',
	HEAVY_TRIPLE_DASH_HORIZONTAL = '\u2505',
	LIGHT_TRIPLE_DASH_VERTICAL = '\u2506',
	HEAVY_TRIPLE_DASH_VERTICAL = '\u2507',
	LIGHT_QUADRUPLE_DASH_HORIZONTAL = '\u2508',
	HEAVY_QUADRUPLE_DASH_HORIZONTAL = '\u2509',
	LIGHT_QUADRUPLE_DASH_VERTICAL = '\u250A',
	HEAVY_QUADRUPLE_DASH_VERTICAL = '\u250B',
	LIGHT_DOWN_AND_RIGHT = '\u250C',
	DOWN_LIGHT_AND_RIGHT_HEAVY = '\u250D',
	DOWN_HEAVY_AND_RIGHT_LIGHT = '\u250E',
	HEAVY_DOWN_AND_RIGHT = '\u250F',
	LIGHT_DOWN_AND_LEFT = '\u2510',
	DOWN_LIGHT_AND_LEFT_HEAVY = '\u2511',
	DOWN_HEAVY_AND_LEFT_LIGHT = '\u2512',
	HEAVY_DOWN_AND_LEFT = '\u2513',
	LIGHT_UP_AND_RIGHT = '\u2514',
	UP_LIGHT_AND_RIGHT_HEAVY = '\u2515',
	UP_HEAVY_AND_RIGHT_LIGHT = '\u2516',
	HEAVY_UP_AND_RIGHT = '\u2517',
	LIGHT_UP_AND_LEFT = '\u2518',
	UP_LIGHT_AND_LEFT_HEAVY = '\u2519',
	UP_HEAVY_AND_LEFT_LIGHT = '\u251A',
	HEAVY_UP_AND_LEFT = '\u251B',
	DOWN_SINGLE_AND_RIGHT_DOUBLE = '\u2552',
	DOWN_DOUBLE_AND_RIGHT_SINGLE = '\u2553',
	DOUBLE_DOWN_AND_RIGHT = '\u2554',
	DOWN_SINGLE_AND_LEFT_DOUBLE = '\u2555',
	DOWN_DOUBLE_AND_LEFT_SINGLE = '\u2556',
	DOUBLE_DOWN_AND_LEFT = '\u2557',
	UP_SINGLE_AND_RIGHT_DOUBLE = '\u2558',
	UP_DOUBLE_AND_RIGHT_SINGLE = '\u2559',
	DOUBLE_UP_AND_RIGHT = '\u255A',
	UP_SINGLE_AND_LEFT_DOUBLE = '\u255B',
	UP_DOUBLE_AND_LEFT_SINGLE = '\u255C',
	DOUBLE_UP_AND_LEFT = '\u255D',
	VERTICAL_SINGLE_AND_RIGHT_DOUBLE = '\u255E',
	VERTICAL_DOUBLE_AND_RIGHT_SINGLE = '\u255F',
	DOUBLE_VERTICAL_AND_RIGHT = '\u2560',
	VERTICAL_SINGLE_AND_LEFT_DOUBLE = '\u2561',
	VERTICAL_DOUBLE_AND_LEFT_SINGLE = '\u2562',
	DOUBLE_VERTICAL_AND_LEFT = '\u2563',
	DOWN_SINGLE_AND_HORIZONTAL_DOUBLE = '\u2564',
	DOWN_DOUBLE_AND_HORIZONTAL_SINGLE = '\u2565',
	DOUBLE_DOWN_AND_HORIZONTAL = '\u2566',
	UP_SINGLE_AND_HORIZONTAL_DOUBLE = '\u2567',
	UP_DOUBLE_AND_HORIZONTAL_SINGLE = '\u2568',
	DOUBLE_UP_AND_HORIZONTAL = '\u2569',
	VERTICAL_SINGLE_AND_HORIZONTAL_DOUBLE = '\u256A',
	VERTICAL_DOUBLE_AND_HORIZONTAL_SINGLE = '\u256B',
	DOUBLE_VERTICAL_AND_HORIZONTAL = '\u256C',
	LIGHT_ARC_DOWN_AND_RIGHT = '\u256D',
	LIGHT_ARC_DOWN_AND_LEFT = '\u256E',
	RIGHT_HEAVY_AND_LEFT_UP_LIGHT = '\u2536',
	UP_LIGHT_AND_HORIZONTAL_HEAVY = '\u2537',
	UP_HEAVY_AND_HORIZONTAL_LIGHT = '\u2538',
	RIGHT_LIGHT_AND_LEFT_UP_HEAVY = '\u2539',
	LEFT_LIGHT_AND_RIGHT_UP_HEAVY = '\u253A',
	HEAVY_UP_AND_HORIZONTAL = '\u253B',
	LIGHT_VERTICAL_AND_HORIZONTAL = '\u253C',
	LEFT_HEAVY_AND_RIGHT_VERTICAL_LIGHT = '\u253D',
	RIGHT_HEAVY_AND_LEFT_VERTICAL_LIGHT = '\u253E',
	VERTICAL_LIGHT_AND_HORIZONTAL_HEAVY = '\u253F',
	UP_HEAVY_AND_DOWN_HORIZONTAL_LIGHT = '\u2540',
	DOWN_HEAVY_AND_UP_HORIZONTAL_LIGHT = '\u2541',
	VERTICAL_HEAVY_AND_HORIZONTAL_LIGHT = '\u2542',
	LEFT_UP_HEAVY_AND_RIGHT_DOWN_LIGHT = '\u2543',
	RIGHT_UP_HEAVY_AND_LEFT_DOWN_LIGHT = '\u2544',
	LEFT_DOWN_HEAVY_AND_RIGHT_UP_LIGHT = '\u2545',
	RIGHT_DOWN_HEAVY_AND_LEFT_UP_LIGHT = '\u2546',
	DOWN_LIGHT_AND_UP_HORIZONTAL_HEAVY = '\u2547',
	UP_LIGHT_AND_DOWN_HORIZONTAL_HEAVY = '\u2548',
	RIGHT_LIGHT_AND_LEFT_VERTICAL_HEAVY = '\u2549',
	LEFT_LIGHT_AND_RIGHT_VERTICAL_HEAVY = '\u254A',
	HEAVY_VERTICAL_AND_HORIZONTAL = '\u254B',
	LIGHT_DOUBLE_DASH_HORIZONTAL = '\u254C',
	HEAVY_DOUBLE_DASH_HORIZONTAL = '\u254D',
	LIGHT_DOUBLE_DASH_VERTICAL = '\u254E',
	HEAVY_DOUBLE_DASH_VERTICAL = '\u254F',
	DOUBLE_HORIZONTAL = '\u2550',
	DOUBLE_VERTICAL = '\u2551',
	LIGHT_ARC_UP_AND_LEFT = '\u256F',
	LIGHT_ARC_UP_AND_RIGHT = '\u2570',
	LIGHT_DIAGONAL_UPPER_RIGHT_TO_LOWER_LEFT = '\u2571',
	LIGHT_DIAGONAL_UPPER_LEFT_TO_LOWER_RIGHT = '\u2572',
	LIGHT_DIAGONAL_CROSS = '\u2573',
	LIGHT_LEFT = '\u2574',
	LIGHT_UP = '\u2575',
	LIGHT_RIGHT = '\u2576',
	LIGHT_DOWN = '\u2577',
	HEAVY_LEFT = '\u2578',
	HEAVY_UP = '\u2579',
	HEAVY_RIGHT = '\u257A',
	HEAVY_DOWN = '\u257B',
	LIGHT_LEFT_AND_HEAVY_RIGHT = '\u257C',
	LIGHT_UP_AND_HEAVY_DOWN = '\u257D',
	HEAVY_LEFT_AND_LIGHT_RIGHT = '\u257E',
	HEAVY_UP_AND_LIGHT_DOWN = '\u257F';
}
