/*  Jcurzez - A free Java implementation of curses
 *  Copyright (C) 2001, 2006  Thomas G. Girard <thomas.g.girard@free.fr>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.nongnu.savannah.jcurzez.peer;

import org.nongnu.savannah.jcurzez.*;

/**
 * This class is needed because when the <b>Jcurses</b>'s shutdown hook is
 * called, there may be other threads that are still using
 * {@link jcurzez.Screen}. So these calls are routed to here, where they
 * are discarded.
 *
 * @see jcurzez.Screen#peer
 *
 * @author Thomas Girard
 * @version 1.0.0
 */
public class NullScreenPeer implements ScreenPeer {
    /** Columns of the previous peer. To be consistent. */
    private final int columns;

    /** Lines of the previous peer. To be consistent. */
    private final int lines;

    /**
     * Creates a new .
     */
    public NullScreenPeer(int columns, int lines) {
	this.columns = columns;
	this.lines = lines;
    }
    /**
     * Does nothing.
     */
    public void gotoXY(int x, int y) {}

    /**
     * Does nothing.
     */
    public void printCell(int x, int y, final Cell cell) {}

    /**
     * Does nothing.
     */
    public void update() {}

    /**
     */
    public int getColumns() { return columns; }

    /**
     */
    public int getLines() { return lines; }

    /**
     */
    public int getFirstX() { return 0; }

    /**
     */
    public int getFirstY() { return 0; }

    /**
     */
    public void setCursorVisibility(int v) {}

    /**
     */
    public void beep() {}

    /**
     */
    public void end() {}
}
