/*  Jcurzez - A free Java implementation of curses
 *  Copyright (C) 2001, 2006  Thomas G. Girard <thomas.g.girard@free.fr>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.nongnu.savannah.jcurzez.test;

import org.nongnu.savannah.jcurzez.*;

/**
 * Tests the screen object.
 *
 * @author Thomas Girard
 * @version 1.0.0
 */
public class ThreadedScreenMain {
    /**
     * Runs the {@link jcurzez.test.Test} program using the <code>Screen</code>
     * object.
     */
    public static void main(String[] args) {
		Screen screen = Screen.getScreen();
		Pen pen = screen.getRectangle().getFillingPen();
		pen.setBackgroundColor(BackgroundColor.BLACK);
		pen.setForegroundColor(ForegroundColor.WHITE);
	
		pen = screen.getRectangle().getDrawingPen();
		pen.setBackgroundColor(BackgroundColor.BLUE);
		pen.setForegroundColor(ForegroundColor.RED);
		screen.beep();
		
		for (int i = 0 ; i < 4; i++){
			new ScreenThread((i/2*12), (i%2*40), i%2==0).start();
		}
		
    }
}


class ScreenThread extends Thread{
	int top; int left;
	boolean stressConcurrency;

	ScreenThread(int t, int l, boolean stress){
		top = t;
		left = l;
		stressConcurrency = stress;
	}
	
	public void run(){
		Area a = new Area(new Rectangle(left,top,left+40,top+12, 
				new Pen(ForegroundColor.CYAN, BackgroundColor.BLACK, Attribute.NORMAL), 
				new Pen(ForegroundColor.RED, BackgroundColor.BLUE, Attribute.BOLD)));
		a.stressConcurrency = stressConcurrency;
		
		test(a, 2500);
		//new Test3(Screen.getScreen(), 1500, top, left);
	}
	
	//Should be no need to synchronize on the window!
	void test(AbstractWindow aw, int pause){
		try{
	//		synchronized(aw){
			aw.getCursor().setXY(0,0);
		    aw.printString("Hello to you, sir.\n");
		    aw.refresh();
	//		}
		    Thread.sleep((int)(Math.random() * (float)pause));
			
	//		synchronized(aw){
		    aw.getCursor().setXY(5,2);
		    aw.printString("How do you do?\n");
		    aw.refresh();
	//		}
		    Thread.sleep((int)(Math.random() * (float)pause));
		    
		    aw.getCursor().setXY(5, 2);
		    aw.insertLine();
		    aw.refresh();
		    Thread.sleep((int)(Math.random() * (float)pause));
	
	//	    synchronized(aw){
		    aw.getCursor().setXY(0,0);
		    aw.insertString("I said: ");
		    aw.refresh();
	//	    }
		    Thread.sleep((int)(Math.random() * (float)pause));
	
		    //character deletion
	//	    synchronized(aw){
		    aw.getCursor().setXY(8,0);
		    aw.deleteChar();
		    aw.insertChar('h');
		    aw.refresh();
	//	    }
		    Thread.sleep((int)(Math.random() * (float)pause));

		}catch(Exception e){
			
		}
	}
}

